using System;
using System.Web;
using System.Web.UI;
using ImageStoreNET.CMS.Data;
using ImageStoreNET.Developer;
using ImageStoreNET.Developer.Core;

namespace EPiServer.Templates.ImageVault.Pages {
    /// <summary>
    /// 
    /// </summary>
    /// <remarks></remarks>
    /// <example></example>
    public partial class ImageUpload : ImageVaultTemplate {
        private static readonly string FILE_UPLOAD = "FILE_UPLOAD";
        /* *******************************************************************
        *  Properties 
        * *******************************************************************/
        #region public int UploadAlbumID
        /// <summary>
        /// Gets the UploadAlbumID of the ImageUpload
        /// </summary>
        /// <value></value>
        public int UploadAlbumID {
            get {
                if (CurrentPage["ImageAlbum"] == null) {
                    return -1;
                }
                return (int)CurrentPage["ImageAlbum"];
            }
        }
        #endregion
        #region public long MaxLength
        /// <summary>
        /// Gets the MaxLength, default is 1MB if not set by EPiServer editor.
        /// </summary>
        /// <value></value>
        public long MaxLength {
            get {
                if (CurrentPage["MaxLength"] != null)
                    return Convert.ToInt64(CurrentPage["MaxLength"]);
                return 1048576;
            }
        }
        #endregion
        #region public bool IsUploading
        /// <summary>
        /// Get/Sets the IsUploading of the ImageUpload
        /// Used to determin if we should abort uploading for large files.
        /// We don't want to stop images from being uploaded by the ImageVault gui.
        /// </summary>
        /// <value></value>
        public bool IsUploading {
            get { return _isUploading; }
            set { _isUploading = value; }
        }
        private bool _isUploading = false;
        #endregion
        /* *******************************************************************
        *  Methods 
        * *******************************************************************/
        #region private IVMetaDataCollection SetMetaData(UploadValues uploadValues)
        /// <summary>
        /// 
        /// </summary>
        /// <param name="uploadValues"></param>
        /// <returns></returns>
        private IVMetaDataCollection SetMetaData(UploadValues uploadValues) {
            IVMetaDataCollection imageMeta = new IVMetaDataCollection();
            if (UploadAlbumID != -1) {
                IVMetaDataCollection albumMetaData = IVDataFactory.GetAlbum(UploadAlbumID).MetaData;
                foreach (IVMetaData metaData in albumMetaData) {
                    IVMetaData meta = new IVMetaData(metaData.Id, uploadValues.GetString(metaData.Name));
                    imageMeta.Add(meta);
                }
            }
            return imageMeta;
        }
        #endregion
        #region private IVCategoryCollection SetCategories(UploadValues uploadValues)
        /// <summary>
        /// 
        /// </summary>
        /// <param name="uploadValues"></param>
        /// <returns></returns>
        private IVCategoryCollection SetCategories(UploadValues uploadValues) {
            IVCategoryCollection albumCategories = IVDataFactory.GetAllCategories();
            IVCategoryCollection imageCategories = new IVCategoryCollection();
            foreach (IVCategory category in albumCategories) {
                if (uploadValues.GetBool(category.Name))
                    imageCategories.Add(new IVCategory(category.Id));
            }
            return imageCategories;
        }
        #endregion
        #region private void SetupUploadView(UploadSetup uploadSetup)
        /// <summary>
        /// 
        /// </summary>
        /// <param name="uploadSetup"></param>
        private void SetupUploadView(UploadSetup uploadSetup) {
            if (UploadAlbumID != -1) {
                IVMetaDataCollection mCol = IVDataFactory.GetAlbum(UploadAlbumID).MetaData;
                uploadSetup.AddFilePicker(FILE_UPLOAD, "Select image");
                uploadSetup.CreateFieldset("Metadata", "metadata");
                foreach (IVMetaData metaData in mCol) {
                    uploadSetup.AddTextBox(metaData.Name, metaData.Name, null, metaData.IsMandatory);
                }
                uploadSetup.EndCurrentFieldset();
                IVCategoryCollection catCol = IVDataFactory.GetAllCategories();
                uploadSetup.CreateFieldset("Categories", "categories");
                foreach (IVCategory category in catCol) {
                    uploadSetup.AddCheckBox(category.Name, category.Name);
                }
                uploadSetup.EndCurrentFieldset();
            }
        }
        #endregion
        #region private int UploadImage(UploadValues uploadValues)
        /// <summary>
        /// 
        /// </summary>
        /// <param name="uploadValues"></param>
        /// <returns></returns>
        private int UploadImage(UploadValues uploadValues) {
            HttpPostedFile file = uploadValues.GetFile(FILE_UPLOAD);
            IsUploading = true;
            int imageId = IVDataFactory.UploadFile(IVDataFactory.CurrentUser, file);
            if (imageId != 0) {
                try {
                    IVMetaDataCollection imageMetaData = SetMetaData(uploadValues);
                    IVCategoryCollection imageCategories = SetCategories(uploadValues);
                    IVDataFactory.UpdateFile(imageId, UploadAlbumID, imageMetaData, imageCategories, IVDataFactory.CurrentUser);
                } catch (Exception ex) {
                    IsUploading = false;
                    IVDataFactory.DeleteFile(imageId);
                    UploadView.Controls.AddAt(0, new LiteralControl("<p class=\"warning\">" + ex.Message + "</p>"));
                    return 0;
                }
            }

            IsUploading = false;
            return imageId;
        }
        #endregion
        #region private void CloseView(bool imageSaved)
        /// <summary>
        /// 
        /// </summary>
        /// <param name="imageSaved"></param>
        private void CloseView(bool imageSaved) {
            if (imageSaved) {
                UploadView.Controls.Clear();
                UploadView.Controls.AddAt(0,new LiteralControl("<p class=\"information\">Your image was successfully uploaded to ImageVault.</p>"));
            }
        }
        #endregion
        #region override protected void OnInit(EventArgs e)
        /// <summary>
        /// 
        /// </summary>
        /// <param name="e"></param>
        override protected void OnInit(EventArgs e) {
            InitializeComponent();
            base.OnInit(e);
        }
        #endregion
        #region private void InitializeComponent()
        /// <summary>
        /// 
        /// </summary>
        private void InitializeComponent() {
            Load += Page_Load;
            IVDataFactory.BeforeAddFileEvent += IVDataFactory_BeforeAddFileEvent;
        }
        #endregion
        /* *******************************************************************
        *  Event methods 
        * *******************************************************************/
        #region protected void Page_Load(object sender, EventArgs e)
        /// <summary>
        /// This method is called when the Page's Load event has been fired.
        /// </summary>
        /// <param name="sender">The <see cref="object"/> that fired the event.</param>
        /// <param name="e">The <see cref="EventArgs"/> of the event.</param>
        protected void Page_Load(object sender, EventArgs e) {

            UploadView.AddControls = SetupUploadView;
            UploadView.SaveUploadView = UploadImage;
            UploadView.CloseUploadView = CloseView;

            if (UploadAlbumID == -1) {
                UploadView.Controls.Clear();
                UploadView.Controls.AddAt(0, new LiteralControl("<p class=\"information\">No upload album set for this page.</p>"));
            }
        }
        #endregion
        #region void IVDataFactory_BeforeAddFileEvent(object source, ImageStoreNET.CMS.Data.IVDataEventArgs e)
        /// <summary>
        /// This method is called when the IVDataFactory's BeforeAddFileEvent event has been fired.
        /// </summary>
        /// <param name="source">The <see cref="object"/> that fired the event.</param>
        /// <param name="e">The <see cref="ImageStoreNET.CMS.Data.IVDataEventArgs"/> of the event.</param>
        void IVDataFactory_BeforeAddFileEvent(object source, IVDataEventArgs e) {
            if(IsUploading && e.File.Length > MaxLength) {
                e.Cancel = true;
                e.File.Delete();
                UploadView.Controls.AddAt(0, new LiteralControl("<p class=\"warning\">The image size exceeds the limitations and can not be saved in ImageVault.</p>"));
            }
        }
        #endregion
    }
}
