using System;
using System.Web.UI;
using System.Web.UI.WebControls;

namespace EPiServer.Templates.ImageVault {
    /// <summary>
    /// Summary description for MetaDataSetup.
    /// </summary>
    /// <remarks>
    /// 2008-02-26 marcus: Created
    /// </remarks>
    public class UploadSetup {
        private readonly UploadView uploadView;
        /* *******************************************************************
         *  Constructors 
         * *******************************************************************/
        #region internal UploadSetup(UploadView uploadView)
        /// <summary>
        /// Initializes a new instance of the <b>MetaDataSetup</b> class.
        /// </summary>
        /// <param name="uploadView"></param>
        internal UploadSetup(UploadView uploadView) {
            this.uploadView = uploadView;
        }
        #endregion
        /* *******************************************************************
         *  Methods 
         * *******************************************************************/
        #region public void AddLabel(string associatedControlID, string labelText, bool mandatory)
        /// <summary>
        /// 
        /// </summary>
        /// <param name="associatedControlID"></param>
        /// <param name="labelText"></param>
        /// <param name="mandatory"></param>
        public void AddLabel(string associatedControlID, string labelText, bool mandatory) {
            Label metaDataLabel = new Label();
            metaDataLabel.AssociatedControlID = associatedControlID;
            metaDataLabel.Text = labelText + (mandatory == true ? " *" : "");
            uploadView.Controls.Add(metaDataLabel);
        }
        #endregion
        #region public void AddTextBox(string name, string labelText, string value, bool mandatory)
        /// <summary>
        /// 
        /// </summary>
        /// <param name="name"></param>
        /// <param name="labelText"></param>
        /// <param name="value"></param>
        /// <param name="mandatory"></param>
        public void AddTextBox(string name, string labelText, string value, bool mandatory) {
            AddLabel(name, labelText, mandatory);
            TextBox textBox = new TextBox();
            textBox.ID = name;
            textBox.Text = value;
            uploadView.Controls.Add(textBox);
        }
        #endregion
        #region public void AddFilePicker(string name, string labelText)
        /// <summary>
        /// 
        /// </summary>
        /// <param name="name"></param>
        /// <param name="labelText"></param>
        public void AddFilePicker(string name, string labelText) {
            AddLabel(name, labelText,false);
            FileUpload filePicker = new FileUpload();
            filePicker.ID = name;
            uploadView.Controls.Add(filePicker);
        }
        #endregion
        #region public void AddCheckBox(string name, string labelText)
        /// <summary>
        /// 
        /// </summary>
        /// <param name="name"></param>
        /// <param name="labelText"></param>
        public void AddCheckBox(string name, string labelText) {
            uploadView.Controls.Add(new LiteralControl("<span>"));
            CheckBox checkBox = new CheckBox();
            checkBox.ID = Convert.ToString(name);
            uploadView.Controls.Add(checkBox);
            AddLabel(name, labelText,false);
            uploadView.Controls.Add(new LiteralControl("</span>"));
        }
        #endregion
        #region public void CreateFieldset(string legend, string cssClass)
        /// <summary>
        /// 
        /// </summary>
        /// <param name="legend"></param>
        /// <param name="cssClass"></param>
        public void CreateFieldset(string legend, string cssClass) {
            uploadView.Controls.Add(new LiteralControl(String.Format("<fieldset class=\"{0}\"><legend>{1}</legend>", cssClass, legend)));
        }
        #endregion
        #region public void EndCurrentFieldset()
        /// <summary>
        /// 
        /// </summary>
        public void EndCurrentFieldset() {
            uploadView.Controls.Add(new LiteralControl("</fieldset>"));
        }
        #endregion
    }
}