using System;
using System.Web.UI;
using System.Web.UI.WebControls;
using ImageStoreNET.Developer;
using ImageStoreNET.Developer.Core;

namespace EPiServer.Templates.ImageVault {
    /// <summary>
    /// Summary description for MetaDataView.
    /// </summary>
    /// <remarks>
    /// 2008-02-26 marcus: Created
    /// </remarks>
    public delegate void AddUploadControls(UploadSetup uploadSetup);
    public delegate int SaveUploadView(UploadValues uploadValues);
    public delegate void CloseUploadView(bool imageSaved);

    [ToolboxData("<{0}:UploadView runat=server></{0}>")]
    public class UploadView : Control, INamingContainer {
        /* *******************************************************************
         *  Properties 
         * *******************************************************************/
        #region public AddUploadControls AddControls
        /// <summary>
        /// Get/Sets the AddControls of the UploadView
        /// </summary>
        /// <value></value>
        public AddUploadControls AddControls {
            get { return _addControls; }
            set { _addControls = value; }
        }
        private AddUploadControls _addControls;
        #endregion
        #region public SaveUploadView SaveUploadView
        /// <summary>
        /// Get/Sets the SaveUploadView of the UploadView
        /// </summary>
        /// <value></value>
        public SaveUploadView SaveUploadView {
            get { return _saveUploadView; }
            set { _saveUploadView = value; }
        }
        private SaveUploadView _saveUploadView;
        #endregion
        #region public CloseUploadView CloseUploadView
        /// <summary>
        /// Get/Sets the CloseUploadView of the UploadView
        /// </summary>
        /// <value></value>
        public CloseUploadView CloseUploadView {
            get { return _closeUploadView; }
            set { _closeUploadView = value; }
        }
        private CloseUploadView _closeUploadView;
        #endregion
        /* *******************************************************************
         *  Methods 
         * *******************************************************************/
        #region private void AddUploadButton()
        /// <summary>
        /// 
        /// </summary>
        private void AddUploadButton() {
            Button uploadButton = new Button();
            uploadButton.ID = "Upload_Button";
            uploadButton.Text = "Upload";
            uploadButton.CssClass = "button";
            uploadButton.Click += UploadButton_Click;
            Controls.Add(uploadButton);
        }
        #endregion
        /* *******************************************************************
         *  Event methods 
         * *******************************************************************/
        #region protected override void OnLoad(EventArgs e)
        /// <summary>
        /// 
        /// </summary>
        /// <param name="e"></param>
        protected override void OnLoad(EventArgs e) {
            base.OnLoad(e);
            if (AddControls == null)
                throw new ApplicationException("The AddControls delegate must be handled.");
            if (SaveUploadView == null)
                throw new ApplicationException("The SaveUploadData delegate must be handled.");
            if(CloseUploadView == null)
                throw new ApplicationException("The CloseUploadView delegate must be handled.");
            AddControls(new UploadSetup(this));
            AddUploadButton();
        }
        #endregion
        #region private void UploadButton_Click(object sender, EventArgs e)
        /// <summary>
        /// This method is called when the UploadButton's Click event has been fired.
        /// </summary>
        /// <param name="sender">The <see cref="object"/> that fired the event.</param>
        /// <param name="e">The <see cref="EventArgs"/> of the event.</param>
        private void UploadButton_Click(object sender, EventArgs e) {
            try {
                if (SaveUploadView(new UploadValues(this)) != 0)
                    CloseUploadView(true);
                else
                    CloseUploadView(false);
            } catch (Exception ex) {
                Controls.AddAt(0, new LiteralControl(String.Format("<p>{0}</p>", ex.Message)));
            }
        }
        #endregion
    }
}